@@ -25,7 +25,11 @@ dt_ = dt_res[(dt_res[f'{flag}'] != 0) & (dt_res[f'{flag}_p'] != 0)]
 dt_ = dt_res[(dt_res[f'{flag}'] < 900000.0) & (dt_res[f'{flag}_p'] < 900000.0)]      
 dt_.replace([np.inf, -np.inf], np.nan, inplace=True)
 dt_.dropna(inplace=True)
-
 correlation, rmse, mape, r2 = calculate_metrics(dt_[f"{flag}"], dt_[f"{flag}_p"])
+
+
+y_true = arry1.flatten()
+y_pred = arry2.flatten()
+correlation, rmse, mape, r2  =  calculate_metrics(y_true, y_pred)
 """
     
\ No newline at end of file
